@@ -176,6 +176,5 @@ class BartForSequenceClassification(Module):
     def forward(self, input_ids: Tensor, attention_mask: Tensor):
         x = self.transformer(input_ids, attention_mask=attention_mask)
         eos_mask = input_ids.eq(self.eos_token_id)
-
         sentence_representation = x[eos_mask].view(x.size(0), -1, x.size(-1))[:, -1]
-        return self.classification_head(sentence_representation)
+        return self.classification_head(sentence_representation).softmax(dim=1)
